from _typeshed import Incomplete as Incomplete

class Lock:
    def locked(self, *args, **kwargs) -> Incomplete: ...
    def release(self, *args, **kwargs) -> Incomplete: ...
    acquire: Incomplete
    def __init__(self, *argv, **kwargs) -> None: ...
